@@ -115,6 +115,24 @@ class BillingClient(AbstractClient):
         
         return await self.call_and_deserialize(**kwargs)
         
+    async def CreateInstance(
+            self,
+            request: models.CreateInstanceRequest,
+            opts: Dict = None,
+    ) -> models.CreateInstanceResponse:
+        """
+        创建一个实例资源，会创建一个新购实例资源的订单，并通过腾讯云账户余额自动支付。调用该接口的账号需要授予finace:trade的权限，否则无法支付成功。目前已接入并支持购买的产品包括：T-Sec-Web应用防火墙、云防火墙、主机安全、主机容器、云安全中心、T-Sec-密钥管理系统。
+        """
+        
+        kwargs = {}
+        kwargs["action"] = "CreateInstance"
+        kwargs["params"] = request._serialize()
+        kwargs["resp_cls"] = models.CreateInstanceResponse
+        kwargs["headers"] = request.headers
+        kwargs["opts"] = opts or {}
+        
+        return await self.call_and_deserialize(**kwargs)
+        
     async def DeleteAllocationRule(
             self,
             request: models.DeleteAllocationRuleRequest,
@@ -1164,4 +1182,40 @@ class BillingClient(AbstractClient):
         kwargs["headers"] = request.headers
         kwargs["opts"] = opts or {}
         
+        return await self.call_and_deserialize(**kwargs)
+        
+    async def RefundInstance(
+            self,
+            request: models.RefundInstanceRequest,
+            opts: Dict = None,
+    ) -> models.RefundInstanceResponse:
+        """
+        退订不再需要的实例，只退还实付金额的部分，已使用的代金券不退还，退还的实付金额默认退到腾讯云账户余额中。调用该接口的账号需要授予finace:RefundInstance的权限，否则无法支付成功。目前已接入并支持退订的产品包括：T-Sec-Web应用防火墙、云防火墙、主机安全、主机容器、云安全中心、T-Sec-密钥管理系统。
+        """
+        
+        kwargs = {}
+        kwargs["action"] = "RefundInstance"
+        kwargs["params"] = request._serialize()
+        kwargs["resp_cls"] = models.RefundInstanceResponse
+        kwargs["headers"] = request.headers
+        kwargs["opts"] = opts or {}
+        
+        return await self.call_and_deserialize(**kwargs)
+        
+    async def RenewInstance(
+            self,
+            request: models.RenewInstanceRequest,
+            opts: Dict = None,
+    ) -> models.RenewInstanceResponse:
+        """
+        续费一台实例，调用该接口续费服务器时，您需要确保您的腾讯云账户余额充足，否则会续费失败。调用该接口的账号需要授予finace:trade的权限，否则无法续费成功。目前已接入并支持续费的产品包括：T-Sec-Web应用防火墙、云防火墙、主机安全、主机容器、云安全中心、T-Sec-密钥管理系统。
+        """
+        
+        kwargs = {}
+        kwargs["action"] = "RenewInstance"
+        kwargs["params"] = request._serialize()
+        kwargs["resp_cls"] = models.RenewInstanceResponse
+        kwargs["headers"] = request.headers
+        kwargs["opts"] = opts or {}
+        
         return await self.call_and_deserialize(**kwargs)
\ No newline at end of file
